@@ -1,3 +1,5 @@
+#' Power for tests with p values
+#' 
 #' This function estimates the power of test routines that calculate p value(s)
 #' @param TS routine to calculate test statistics.
 #' @param f routine that generates data.
@@ -8,14 +10,14 @@
 #' @return A matrix of power values
 
 power_newtest <- function(TS, f, param_alt, TSextra, alpha=0.05, B=1000) {
-     Continuous=ifelse("vals" %in% names(formals(TS)), FALSE, TRUE)  
+     Continuous=ifelse("vals" %in% names(formals(TS)), FALSE, TRUE) 
      dta=f(param_alt[1])
      if(Continuous) {
-        if("aaa"%in% names(TSextra)) tmp=TS(dta$x, dta$y)
+        if(length(formals(TS))==2) tmp=TS(dta$x, dta$y)
         else tmp=TS(dta$x, dta$y, TSextra)
      }
      else {
-        if("aaa"%in% names(TSextra)) tmp=TS(dta$x, dta$y, dta$vals)
+       if(length(formals(TS))==3) tmp=TS(dta$x, dta$y, dta$vals)
         else tmp=TS(dta$x, dta$y, dta$vals, TSextra)
      } 
      pwr=matrix(0, length(param_alt), length(TS))
@@ -25,11 +27,11 @@ power_newtest <- function(TS, f, param_alt, TSextra, alpha=0.05, B=1000) {
         for(i in 1:B) {
           dta=f(param_alt[j])
           if(Continuous) {
-             if("aaa"%in% names(TSextra)) tmp=TS(dta$x, dta$y)
+            if(length(formals(TS))==2) tmp=TS(dta$x, dta$y)
              else tmp=TS(dta$x, dta$y, TSextra)
           }
           else {
-            if("aaa"%in% names(TSextra)) tmp=TS(dta$x, dta$y, dta$vals)
+            if(length(formals(TS))==3) tmp=TS(dta$x, dta$y, dta$vals)
             else tmp=TS(dta$x, dta$y, dta$vals, TSextra)
           }
           pwr[j, ]=pwr[j, ]+ifelse(tmp<alpha,1,0) 
